@@ -11,35 +11,42 @@ from timepiece.entries.models import Entry
 
 
 DATE_FORM_FORMAT = '%Y-%m-%d'
+INPUT_FORMATS = [DATE_FORM_FORMAT]
+
+
+class TimepieceSplitDateTimeWidget(forms.SplitDateTimeWidget):
+
+    def __init__(self, *args, **kwargs):
+        kwargs['date_format'] = kwargs.get('date_format', DATE_FORM_FORMAT)
+        super(TimepieceSplitDateTimeWidget, self).__init__(*args, **kwargs)
+
+
+class TimepieceDateInput(forms.DateInput):
+
+    def __init__(self, *args, **kwargs):
+        kwargs['format'] = kwargs.get('format', DATE_FORM_FORMAT)
+        super(TimepieceDateInput, self).__init__(*args, **kwargs)
 
 
 class DateForm(forms.Form):
-    DATE_FORMAT = DATE_FORM_FORMAT
-
     from_date = forms.DateField(label='From', required=False,
-        input_formats=(DATE_FORMAT,),
-        widget=forms.DateInput(format=DATE_FORMAT))
+        input_formats=INPUT_FORMATS, widget=TimepieceDateInput())
     to_date = forms.DateField(label='To', required=False,
-        input_formats=(DATE_FORMAT,),
-        widget=forms.DateInput(format=DATE_FORMAT))
+        input_formats=INPUT_FORMATS, widget=TimepieceDateInput())
 
     def clean(self):
-        data = self.cleaned_data
-        from_date = data.get('from_date', None)
-        to_date = data.get('to_date', None)
+        from_date = self.cleaned_data.get('from_date', None)
+        to_date = self.cleaned_data.get('to_date', None)
         if from_date and to_date and from_date > to_date:
-            err_msg = 'The ending date must exceed the beginning date'
-            raise forms.ValidationError(err_msg)
-        return data
+            raise forms.ValidationError('The ending date must exceed the '
+                    'beginning date.')
+        return self.cleaned_data
 
     def save(self):
         from_date = self.cleaned_data.get('from_date', '')
         to_date = self.cleaned_data.get('to_date', '')
-        returned_date = to_date
-
-        if returned_date:
-            returned_date += relativedelta(days=1)
-        return (from_date, returned_date)
+        to_date = to_date + relativedelta(days=1) if to_date else to_date
+        return (from_date, to_date)
 
 
 class YearMonthForm(forms.Form):
